/**
 * @file Parser.java
 */

import java.util.* ;
import java.io.* ;

/**
 * @class Parser
 * @brief Classe parseur qui transcrit un fichier texte en un autre en adaptant la casse.
 */
public class Parser
{
    public static void main(String[] args)
    {
	// vérifie les arguments
        if (args.length != 2)
        {
            System.out.println("Usage: java Parser <inputFileName> <outputFileName>") ;
            System.exit(0) ;
        }
        final String fileIn = args[0] ;
        final String fileOut = args[1] ;

        try
        {
            Word[] listOfWords ;
            String line = null ;

	   // Lecture/écriture par tampon : une ligne à la fois
            BufferedReader input = new BufferedReader(new FileReader(fileIn)) ;
            BufferedWriter output = new BufferedWriter(new FileWriter(fileOut)) ;
            try
            {
		// Pour toute ligne lue
                while ((line = input.readLine()) != null)
                { 
		  // on la découpe en une liste de mots
                    listOfWords = Word.cutPhrase2Words(line) ;

		  // Pour tout mot de la liste
                    for (int i = 0 ; i < Word.countNbWords(line) ; ++i)
                    {
		      // on convertit sa casse
		      String s = listOfWords[i].toFirstUpperCase() ;
		      // on l'écrit dans le fichier de sortie en ajoutant un espace derrière
                        output.write(s) ;
                        output.write(" ") ;
                    }
                    output.newLine() ; // on va à la ligne après chaque ligne lue
                }
            }
            finally // si jamais il y a un problème, on passe tout de même ici
            {
                input.close() ;
                output.close() ;
            }
        }
        catch (IOException e)
        {
            e.printStackTrace() ;
        }

        System.out.println("Le texte qui a été lu contien exactement " + Word.nbTreatedWords() + " mots") ;
    }
}
